@@ -2,6 +2,7 @@
 import os
 import shutil
 def new(command, path, name, number, Suffix=''):
+    Creation_time="2021/8/30"
     """NEW Folder"""
     if command == 'n':
         path_new = path
@@ -54,6 +55,7 @@ def new(command, path, name, number, Suffix=''):
 
 def new_del(command, path):
     import shutil
+    Creation_time="2021/8/30"
     """del File"""
     if command == 'del':
         path_del = path
@@ -72,6 +74,7 @@ def new_del(command, path):
         except:
             print(f"NO {path_folder} folders !")
 def new_input(file, message=''):
+    Creation_time="2021/8/30"
     input_message = message
     input_file = file
     try:
@@ -83,6 +86,7 @@ def new_input(file, message=''):
         print(f"file {input_file} does not exist!")
 
 def new_print(path):
+    Creation_time="2021/8/30"
     try:
         print_wj = open(path, 'r', encoding='utf-8')
         print_sc = print_wj.read()
@@ -100,6 +104,7 @@ def new_add(path, message=''):
         print("Not {path} file !")
 
 def filename(file, name):
+    Creation_time="2021/8/30"
     try:
         file_new = file
         file_name = name
@@ -113,6 +118,7 @@ def filename(file, name):
         print(f"Wrong! You may have entered an invalid path, or the path is empty! Your path is: {file_new}")
 
 def move(path, file):
+    Creation_time="2021/8/30"
     try:
         shutil.move(path,file)
         print(f"成功 将 {path} 移动至 {file}")
@@ -128,3 +134,35 @@ def move(path, file):
             print(f"没有 {path} 路径！")
             print(f"No {path} path!")
             #shutil.move(path,file)
+
+def copyfor(path):
+    Creation_time="2021/9/1"
+    for l,k,j in os.walk(path):
+        print(l,k,j)
+
+def copy(cmd, paths, file, number):
+    Creation_time="2021/9/1"
+    if cmd == 'file':
+        shutil.copyfile(paths,file)
+        print(f"成功 将{paths} 复制到 {file}")
+        print(f"Successfully copied {paths} to {file}")
+    if cmd == 'copy':
+        shutil.copy(paths,file)
+        print(f"成功将 {paths} 复制到 {file}")
+        print(f"Successfully copied {paths} to {file}")
+    if cmd == 'tree':
+        if int(number) > 1:
+            for i in range(int(number)):
+                if int(i) == 0:
+                    shutil.copytree(paths,file)
+                    print(f"创建文件夹{file} 将{paths}复制进去")
+                    print(f"Create a folder {file} and copy {paths} into it")
+                else:
+                    shutil.copytree(paths,file+f"{i}")
+                    print(f"创建文件夹{file} 将{paths}{i}复制进去")
+                    print(f"Create a folder {file} and copy {paths}{i} into it")
+        if int(number) <= 1:
+            shutil.copytree(paths,file)
+            print(f"创建文件夹{file} 将{paths}复制进去")
+            print(f"Create a folder {file} and copy {paths} into it")
+#try
